{% extends "base.html" %}
{% import "macros.html" as m %}
{% block title %}{{ meta.name }} — live — mgf-fed-web{% endblock %}

{% block main %}
{% include "_project_header.html" %}

{% if meta.wired %}
  {% set active_tab = "inprogress" %}
  {% include "_project_nav.html" %}

  <div class="fw-view-h">
    <h1 class="fw-view-h__t">Follow live</h1>
    <span class="fw-view-h__s mono">in-progress · live activity {{ m.derived() }} telemetry — ephemeral, never gated</span>
  </div>

  {% include "_live_pane.html" %}
{% endif %}
{% endblock %}
