{% extends "base.html" %}
{% import "macros.html" as m %}
{% block title %}{{ meta.name }} — mgf-fed-web{% endblock %}

{% block main %}
{% include "_project_header.html" %}

{% if meta.wired %}
  {% set active_tab = active_lens %}
  {% include "_project_nav.html" %}
  {% include lens_template %}
{% endif %}
{% endblock %}
