{% import "macros.html" as m %}
{% if not view.ok %}
  {{ m.absence(view) }}
{% elif view['items'] %}
  <p class="lead fw-lede">Your worklist — every open task whose <span class="mono">owner == founder</span>. Because only
  you enact these, this is literally what's waiting on you. Reported.</p>
  <div class="fw-cards">
    {% for t in view['items'] %}{{ m.task_card(t) }}{% endfor %}
  </div>
{% else %}
  {{ m.empty_inline(view.empty_title, view.empty_reason) }}
{% endif %}
