{# The project tab strip: the generated/ lenses, then the Feedback loop + the
   print Review pack. `active_tab` is the active lens id, or "feedback"/"review".
   `open_rounds` (optional) badges feedback awaiting a response. #}
<nav class="tabs fw-tabs" aria-label="Lenses">
  {% for lid in lenses %}
  <a class="tab {% if active_tab == lid %}tab--active{% endif %}" href="/p/{{ meta.slug }}/{{ lid }}">{{ lens_labels[lid] }}</a>
  {% endfor %}
  <a class="tab fw-tab--feedback {% if active_tab == 'feedback' %}tab--active{% endif %}" href="/p/{{ meta.slug }}/feedback">
    Feedback{% if open_rounds %} <span class="fw-tab-badge" title="{{ open_rounds }} open round(s)">{{ open_rounds }}</span>{% endif %}
  </a>
  <a class="tab fw-tab--review {% if active_tab == 'review' %}tab--active{% endif %}" href="/p/{{ meta.slug }}/review-pack">Review pack</a>
</nav>
